@@ -82,9 +82,9 @@ final class TaskId
 	const DELETE_DOMAIN_SSL = 12;
 
 	/**
-	 * TYPE=20 COSTUMERBACKUP
+	 * TYPE=20 CUSTUMER DATA DUMP
 	 */
-	const CREATE_CUSTOMER_BACKUP = 20;
+	const CREATE_CUSTOMER_DATADUMP = 20;
 
 	/**
 	 * TYPE=99 REGENERATE CRON
